@@ -484,14 +484,7 @@ class UCR(predict_system.TextSystem):
         
         postprocess_params.rec_char_dict_path = str(
             Path(__file__).parent / postprocess_params.rec_char_dict_path)
-        
-        # postprocess_params.cls_config_location = str(
-        #     Path(__file__).parent / postprocess_params.cls_config_location)
-        # postprocess_params.det_config_location = str(
-        #     Path(__file__).parent / postprocess_params.det_config_location)
-        # postprocess_params.rec_config_location = str(
-        #     Path(__file__).parent / postprocess_params.rec_config_location)
-
+        print(postprocess_params.rec_char_dict_path)
         super().__init__(postprocess_params)
 
     def predict(self, img, det=True, rec=True):
